@@ -12,11 +12,11 @@ class ClassesResponse(BaseModel):
     Attributes
     ----------
     class: (str, required) labelled class
-    score: (int, optional) confidence score in class
+    score: (float, optional) confidence score in class
     """
 
     class_field: str = Field(None, alias="class")
-    score: int = None
+    score: float = None
 
 
 class ClassificationResponse(ResponseObject):
